@@ -2,7 +2,7 @@ import json
 from typing import Optional
 
 from aiiohttp import AiohttpSession
-from base.model import Model
+from ai_openchat.model import Model
 from base.session import BaseSession
 from utils.token import validate_token
 
